@@ -2,7 +2,11 @@ pub mod error;
 pub mod parse;
 pub mod path;
 pub mod predicate;
-pub mod schemas;
+
+pub mod schemas {
+    include!(concat!(env!("OUT_DIR"), "/src/schemas/mod.rs"));
+}
+
 pub mod step;
 
 pub use error::CompilationError;
